Add the full path of CosMx/Xenium/Merscope transcript csv data to Kandinsky data
AddTxPath(seurat, path)a Seurat object containing Kandinsky data (KanData())
character string indicating the path for the transcript coordinates file from CoxMx/Xenium/Merscope platforms
Seurat object with new tx slot added to Kandinsky data