Extract all Kandinsky data or specific slots from Seurat object

KanData(object, which = NULL)

# S4 method for class 'Kandinsky'
KanData(object, which = NULL)

# S4 method for class 'Seurat'
KanData(object, which = NULL)

# S4 method for class 'Kandinsky'
KanData(object, which = NULL) <- value

# S4 method for class 'Seurat'
KanData(object, which = NULL) <- value

Arguments

object

Seurat or Kandinsky object

which

name of Kandinksy slots to extract. If NULL, all Kandinsky data will be extracted

value

object or variable to assign to the selected Kandinksy slot