CellCharter is called thrugh reticulate and interacts with Seurat/Kandinsky object after anndata conversion with anndataR

cellcharter_coloc(
  data = NULL,
  label = NULL,
  seed = 347548,
  log_fold_change = F,
  python_path = NULL,
  max.cap = 0.9,
  return.mat = T
)

Arguments

data

a Seurat object containing Kandinsky data slot

label

name of the metadata column variable containing cell type annotation to be used for join count test

seed

numeric, random seed

log_fold_change

boolean, whether to return default CellCharter colocalisation scores (observed - expected) or their log-fold change version (log2(observed/expected))

python_path

path of python environment with MESA and its dependencies installed

max.cap

numeric, quantile cap to apply to colocalisation coefficients for colour scale creation. Default is 0.9, will set the coefficient value limit to the 90% quantile of all coefficients

return.mat

boolean, whether returning only colocalization plot (FALSE) or also a dataframe containing colocalization test results

Value

a colocalization plot (when return.mat is FALSE) or a list containing colocalization plot and results in a tabular format

Details

CellCharter must be installed within a python environment together with its dependencies (squidpy)