Giotto colocalisation performed by calling the R package Giotto through Kandinsky

giotto_coloc(
  data = NULL,
  label = NULL,
  nperms = 1000,
  python_path = NULL,
  max.cap = 0.9,
  return.mat = T
)

Arguments

data

a Seurat object containing Kandinsky data slot

label

name of the metadata column variable containing cell type annotation to be used for join count test

nperms

numeric, number of random permutations to perform for colocalisation test

python_path

path of python environment with MESA and its dependencies installed

max.cap

numeric, quantile cap to apply to colocalisation coefficients for colour scale creation. Default is 0.9, will set the coefficient value limit to the 90% quantile of all coefficients

return.mat

boolean, whether returning only colocalization plot (FALSE) or also a dataframe containing colocalization test results

Value

a colocalization plot (when return.mat is FALSE) or a list containing colocalization plot and results in a tabular format

Details

Giotto must be installed within the same environmnent of Kandinsky