hoodscanR colocalisation performed by calling the R package hoodscanR through Kandinsky

hoodscanR_coloc(
  data = NULL,
  k = 100,
  label = NULL,
  sample_key = NULL,
  max.cap = 1,
  return.mat = T
)

Arguments

data

Seurat object containing Kandinsky data

k

numeric, number of nearest neighbours to consider for hoodscanR clustering

label

character string specifying the variable name to be used to defne cell annotation groups

sample_key

character string specifying a variable stored in the Seurat object to use as sample/batch annotation. If not NULL, neighbour networks will be defined separately for each sample/batch. Default is NULL

max.cap

numeric, quantile cap to apply to colocalisation coefficients for colour scale creation. Default is 1, will set the coefficient value limit to the highest value of all coefficients

return.mat

boolean, whether returning only colocalization plot (FALSE) or also a dataframe containing colocalization test results

Value

a colocalization plot (when return.mat is FALSE) or a list containing colocalization plot and results in a tabular format

Details

hoodscanR must be installed within the same environmnent of Kandinsky..