R/05_Hot_cold_spot_analysis_.R
hotspot_count.RdSummarise number and min/max/median size of hot- and cold-spots for a variable of choice.
hotspot_count(data = NULL, feature = NULL, ...)a Seurat object containing Kandinsky data (KanData())
character string specifying the name of the feature(s) used to compute Getis-Ord Gi* statistics
arguments passed to hotspot_analysis function
data.frame summarising hotspot and coldspot size and number for each variable of interest
This function will look for the presence of already existing hotspot annotation in the meta.data of Seurat object for the variable(s) of interest.
If no annotations exist, the hotspot_analysis() function will be automatically called.