Call multi_jc() function to perform colocalization test, and plot results in the form of a heatmap

jc_coloc(
  data = NULL,
  label = NULL,
  max.cap = 0.9,
  return.mat = F,
  wc.type = c("mat", "listw")
)

Arguments

data

a Seurat object containing Kandinsky data slot

label

name of the metadata column variable containing cell type annotation to be used for join count test

max.cap

numeric, quantile cap to apply to colocalisation coefficients for colour scale creation. Default is 0.9, will set the coefficient value limit to the 90% quantile of all coefficients

return.mat

boolean, whether returning only colocalization plot (FALSE) or also a dataframe containing colocalization test results

wc.type

input type to use to extract summary weight constants used to calculate join count statistics. Must be one of the following: "listw", "mat"

Value

a colocalization plot (when return.mat is FALSE) or a list containing colocalization plot and results in a tabular format

See also

squidpy_coloc(), cellcharter_coloc(), hoodscanR_coloc(), giotto_coloc() for alternative colocalisation methods