MESA is called thrugh reticulate and interacts with Seurat/Kandinsky object after anndata conversion with anndataR

mesa_clust(
  data = NULL,
  k = 10,
  n_clust = 10,
  seed = 347548,
  python_path = NULL
)

Arguments

data

a Seurat object containing Kandinsky data

k

numeric, number of nearest neighbours to consider for MESA gene expression aggregation

n_clust

numeric, number of expected clusters

seed

numeric, random seed

python_path

path of python environment with MESA and its dependencies installed

Value

updated Seurat object with 'mesa_clusters' annotation added to metadata slot

Details

MESA must be installed within a python environment together with its dependencies (scanpy,sklearn.cluster)