Given cell type composition of single-cell neighbourhood, calculate Shannon entropy associated with each neighbourhood

nb_entropy(seurat)

Arguments

seurat

seurat object containing Kandinsky data slot with pre-computed neighbourhood composition matrix in nnMat slot

Value

seurat object with new metadata variable reporting neighbourhood entropy for each cell