data objects included in the KanData slots based on the real Seurat object. By default Kandinsky data will not be subsetted together with Seurat during normal filtering steps using subset() or row/column names subset (e.g. seurat[,ids]). Use update_kandinsky() to check and fix discrepancies between Seurat and KanData cell/spot ids

update_kandinsky(seurat = NULL)

# S4 method for class 'Seurat'
update_kandinsky(seurat = NULL)

Arguments

seurat

a Seurat object containing Kandinsky data (KanData())

Value

Seurat object with updated Kandinsky data