Kandinsky is a list object storing spatial data and information for spatial transcriptomic dataset analysed through Seurat.
platformsequencing technology
nbweighted neighbour list object created with the packagespdep
sfgeometry data frame created with the package sf and containing cell/spot coordinates
nb.typecharacter indicating the neighbouring strategy used to initialize Kandinsky object. Must be one of the following: Q, K, C, M
nnMatlist object containing nearest neighbour matrix created with one of the nnMat functions implemented in Kandinsky
spot_distancenumeric value indicating centroid-to-centroid distance between Visium spots or Visium HD bins
texturedata.frame containing GLCM texture features extracted from Visium H&E slide image
txcharacter string indicating the path for the transcript coordinates file from CoxMx/Xenium/Merscope platforms
fov_maskgeometry data frame created with the package sf and containing CosMx FOVs bounding box coordinates
imgVisium H&E or any other tissue slide image stored as a SpatRaster or SpatrasterCollection object via the package terra
maskmasked H&E image obtained via the Kandinsky function he_mask and stored as a SpatRaster or SpatrasterCollection object via the package terra