Giotto clustering performed by calling the R package Giotto through Kandinsky
giotto_clust(
data = NULL,
n_clust = 5,
ngenes = NULL,
betas = c(0, 5),
seed = 347548,
cores = 1,
python_path = NULL
)Seurat object containing Kandinsky data
numeric, number of expected clusters. Can be a single number or a numeric vector if multiple cluster numbers needs to be tested
numeric, number of top variable genes to consider for HMRF domain identification Default is 250. If dataset contains less than 250 genes, all genes will be considered.
numeric vector of beta values to use for Giotto HMRF domain identification. Currently only supports two beta values at a time
numeric, random seed.
numeric, number of cores to use for parallelization
path of python environment with MESA and its dependencies installed
updated Seurat object with 'giotto_clusters' annotation added to metadata slot for each beta value
Giotto must be installed within the same environmnent of Kandinsky