hoodscanR clustering performed by calling the R package hoodscanR through Kandinsky
hoodscanR_clust(
data = NULL,
k = 100,
label = NULL,
n_clust = 5,
sample_key = NULL
)Seurat object containing Kandinsky data
numeric, number of nearest neighbours to consider for hoodscanR clustering
character string specifying the variable name to be used to defne cell annotation groups
numeric, number of expected clusters. Can be a single number or a numeric vector if multiple cluster numbers needs to be tested
character string specifying a variable stored in the Seurat object to use as sample/batch annotation. If not NULL, neighbour networks will be defined separately for each sample/batch. Default is NULL
updated Seurat object with 'hoodscanR_clusters' annotation added to metadata slot
hoodscanR must be installed within the same environmnent of Kandinsky