hoodscanR colocalisation performed by calling the R package hoodscanR through Kandinsky
hoodscanR_coloc(
data = NULL,
k = 100,
label = NULL,
sample_key = NULL,
max.cap = 1,
return.mat = T
)Seurat object containing Kandinsky data
numeric, number of nearest neighbours to consider for hoodscanR clustering
character string specifying the variable name to be used to defne cell annotation groups
character string specifying a variable stored in the Seurat object to use as sample/batch annotation. If not NULL, neighbour networks will be defined separately for each sample/batch. Default is NULL
numeric, quantile cap to apply to colocalisation coefficients for colour scale creation. Default is 1, will set the coefficient value limit to the highest value of all coefficients
boolean, whether returning only colocalization plot (FALSE) or also a dataframe containing colocalization test results
a colocalization plot (when return.mat is FALSE) or a list containing colocalization plot and results in a tabular format
hoodscanR must be installed within the same environmnent of Kandinsky..