ISCHIA-inspired K-Means clustering
kmeans_clust(data = NULL, n_clust = 1:10, label = NULL, seed = 347548)Seurat object containing Kandinsky data
numeric, number of expected clusters. Can be a single number or a numeric vector if multiple cluster numbers needs to be tested
character string specifying the variable name to be used to defne cell annotation groups
numeric, random seed.
updated Seurat object with 'kmeans_clusters' annotation added to metadata slot
When more than one cluster configurations are provided, the function chooses the one minimizing Within-Cluster Sum of Squares (WSS), as implemented in the R package ISCHIA