MESA is called thrugh reticulate and interacts with Seurat/Kandinsky object after anndata conversion with anndataR
mesa_clust(
data = NULL,
k = 10,
n_clust = 10,
seed = 347548,
python_path = NULL
)updated Seurat object with 'mesa_clusters' annotation added to metadata slot
MESA must be installed within a python environment together with its dependencies (scanpy,sklearn.cluster)