R/03_NB_based_cell_comparison.R
nb_entropy.RdGiven cell type composition of single-cell neighbourhood, calculate Shannon entropy associated with each neighbourhood
nb_entropy(seurat)seurat object with new metadata variable reporting neighbourhood entropy for each cell