R/06_Utils.R
visiumize.RdThis function collapses single-cell gene expression data into spots or bins, depending on the desired format.
a Seurat object containing Kandinsky data slot
character, define the final data format. Must be one between 'spots' (Visium) and 'bins' (Visium-HD)
character string specifying the variable name to be used to defne cell annotation groups
numeric, Visium-HD bin resolution when style is set to 'bins'.
spatial neighbour method to apply to the collapsed data. See kandinsky_init documentation
numeric, number of nearest neighbours to be set when 'nb.method = K'
numeric, maximum centroid distance threshold to be set when 'nb.method = C | M'
boolean, whether or not filter Delaunay network to keep sphere of influence (SOI) graph. Default is FALSE
numeric, number of concentric contiguous layers to include in spot neighbourhood. Only Applied when 'nb.method = Q'. Default is 1
a new Seurat object containing newly generated Visium/Visium-HD data and associated Kandinsky data